.. _recipe_asr.magnetic_anisotropy:

asr.magnetic_anisotropy
=======================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.magnetic_anisotropy`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.magnetic_anisotropy.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.magnetic_anisotropy

or as a python module

.. code-block:: console

   $ python -m asr.magnetic_anisotropy

Detailed description
--------------------
Magnetic anisotropy.

Steps
-----


asr.magnetic_anisotropy
^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.magnetic_anisotropy.main
   